﻿using MedicalDatabaseContracts.Models;
using Microsoft.Extensions.Logging;
using Npgsql;
using System.Data;

namespace MedicalPostgresqlDatabase.Storages
{
    public class DoctorStorage : AbstractPostgresqlStorage<Doctor>
    {
        public DoctorStorage(ILogger<DoctorStorage> logger) : base(logger, "doctors", "doctor_id", "doctors_id_seq") { }

        protected override Doctor CreateEntityFromReader(NpgsqlDataReader reader)
        {
            return new Doctor
            {
                Id = Convert.ToInt32(reader.GetValue(PRIMARY_KEY_COLUMN_NAME)),
                Name = Convert.ToString(reader.GetValue("name")),
                Surname = Convert.ToString(reader.GetValue("surname")),
                Patronymic = Convert.ToString(reader.GetValue("patronymic")),
                PhoneNumber = Convert.ToString(reader.GetValue("phone_number")),
                SpecializationId = Convert.ToInt32(reader.GetValue("specialization_id"))
            };
        }

        protected override Dictionary<string, string> GetEntityAttributesDictionary(Doctor item)
        {
            var dict = new Dictionary<string, string>
            {
                { PRIMARY_KEY_COLUMN_NAME, item.Id.ToString() },
                { "name", item.Name },
                { "surname", item.Surname },
                { "patronymic", item.Patronymic },
                { "phone_number", item.PhoneNumber },
                { "specialization_id", item.SpecializationId.ToString() }
            };
            return dict;
        }
    }
}
