﻿using MedicalDatabaseContracts;
using MedicalDatabaseContracts.Models;
using Microsoft.Extensions.Logging;

namespace MedicalView
{
    public partial class FormAbstractList<T> : Form where T : AbstractModel
    {
        protected ILogger _logger;
        protected IStorage<T> _storage;
        public FormAbstractList(ILogger<FormAbstractList<T>> logger, IStorage<T> storage)
        {
            InitializeComponent();
            _logger = logger;
            _storage = storage;
        }

        private void FormAbstractList_Load(object sender, EventArgs e)
        {
            LoadData();
        }

        private void RefreshItemsToolStripMenuItem_Click(object sender, EventArgs e)
        {
            LoadData();
        }

        private void AddItemToolStripMenuItem_Click(object sender, EventArgs e)
        {
            // code
        }

        private void EsitItemToolStripMenuItem_Click(object sender, EventArgs e)
        {
            // code
        }

        private void DeleteItemToolStripMenuItem_Click(object sender, EventArgs e)
        {
            // code
        }

        protected virtual void LoadData()
        {
            SetStatusStripText("Загрузка списка...");
            try
            {
                long elapsed;
                var items = _storage.GetAll(out elapsed);

                dataGridView.DataSource = items;
                dataGridView.Columns["Id"].DisplayIndex = 0;
                foreach (DataGridViewTextBoxColumn column in dataGridView.Columns)
                {
                    if (column.Name.Contains("Id"))
                    {
                        column.Visible = false;
                    }
                }
                dataGridView.ReadOnly = true;

                _logger.LogInformation("Список загружен успешно");
                SetStatusStripText($"Готово. Загружено записей: {items.Count}, время загрузки {elapsed} мск");
            }
            catch (Exception ex)
            {
                string errorMessage = "Ошибка загрузки списка";
                _logger.LogError(string.Join(", ", errorMessage, $"\"{ex.Message}\""));
                MessageBox.Show(string.Join("\n\n", errorMessage, $"{ex.Message}"), "Ошибка", MessageBoxButtons.OK, MessageBoxIcon.Error);
                SetStatusStripText($"Ошибка загрузки");
            }
        }
        protected virtual void SetStatusStripText(string text)
        {
            toolStripStatusLabel.Text = text;
        }
    }
}
